from django.apps import AppConfig


class RelationsConfig(AppConfig):
    name = "apis_core.apis_relations"
